@@ -86,6 +86,9 @@ SEXP do_tempfile(SEXP call, SEXP op, SEXP args, SEXP env)
     return (ans);
 }
 
+#include <sys/types.h>
+#include <sys/stat.h>
+
 SEXP do_unlink(SEXP call, SEXP op, SEXP args, SEXP env)
 {
     SEXP  fn, ans;
@@ -93,6 +96,7 @@ SEXP do_unlink(SEXP call, SEXP op, SEXP args, SEXP env)
     WIN32_FIND_DATA find_data;
     HANDLE fh;
     int i, nfiles, failures = 0;
+    struct stat sb;
 
     checkArity(op, args);
     fn = CAR(args);
@@ -103,6 +107,13 @@ SEXP do_unlink(SEXP call, SEXP op, SEXP args, SEXP env)
 	strcpy(tmp, CHAR(STRING(fn)[i]));
 	for(p = tmp; *p != '\0'; p++)
 	    if(*p == '/') *p = '\\';
+	if(stat(tmp, &sb))
+	    /* Is this a directory? */
+	    if(sb.st_mode & _S_IFDIR) {
+		if(rmdir(tmp)) failures++;
+		continue;
+	    }
+	/* Regular file (or more) */
 	strcpy(dir, tmp);
 	if ((p = strrchr(dir, '\\'))) *(++p) = '\0'; else *dir = '\0';
 	/* check for wildcard matches */
@@ -128,7 +139,6 @@ SEXP do_unlink(SEXP call, SEXP op, SEXP args, SEXP env)
 
 SEXP do_helpstart(SEXP call, SEXP op, SEXP args, SEXP env)
 {
-    SEXP  ans;
     char *home, buf[MAX_PATH];
     FILE *ff;
 
@@ -148,10 +158,7 @@ SEXP do_helpstart(SEXP call, SEXP op, SEXP args, SEXP env)
     }
     fclose(ff);
     ShellExecute(NULL, "open", buf, NULL, home, SW_SHOW);
-    PROTECT(ans = allocVector(STRSXP, 1));
-    STRING(ans)[0] = mkChar("");
-    UNPROTECT(1);
-    return (ans);
+    return R_NilValue;
 }
 
 static int nhfiles = 0;
