@@ -14,14 +14,14 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifndef FORTRAN_H
 #include "Mathlib.h"
 #define FORTRAN_H
 
-#include "Platform.h"
+#include "Rconfig.h"
 #include "Complex.h"
 
 	/* General F2C Macros */
