@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifndef PRINT_H_
@@ -23,7 +23,16 @@
 #include "PrtUtil.h"
 #include "Defn.h"
 
-extern SEXP print_na_string;
+typedef struct {
+    int width;
+    int na_width;
+    int digits;
+    int gap;
+    int quote;
+    int right;
+    SEXP na_string;
+} R_print_par_t;
+extern R_print_par_t R_print;
 
 /* Computation of printing formats */
 void formatString(SEXP*, int, int*, int);
@@ -36,13 +45,15 @@ char *EncodeElement(SEXP, int, int);
 void MatrixColumnLabel(SEXP, int, int);
 void RightMatrixColumnLabel(SEXP, int, int);
 void LeftMatrixColumnLabel(SEXP, int, int);
-void MatrixRowLabel(SEXP, int, int);
+void MatrixRowLabel(SEXP, int, int, int);
 
 /* In Defn.h (and MUST be there):
    CustomPrintValue,  PrintValue, PrintValueRec */
 void printArray(SEXP, SEXP, int, SEXP);
-void printMatrix(SEXP, int, SEXP, int, int, SEXP, SEXP);
-void printNamedVector(SEXP, SEXP, int);
+void printMatrix(SEXP, int, SEXP, int, int, SEXP, SEXP, char*, char*);
+void printNamedVector(SEXP, SEXP, int, char*);
 void printVector(SEXP, int, int);
+/* Offset for rowlabels if there are named dimnames */
+#define MIN_LBLOFF 2
 
 #endif
