@@ -3,11 +3,12 @@ ar.ols <- function (x, aic = TRUE, order.max = NULL, na.action = na.fail,
                     demean = TRUE, series = NULL, ...)
 {
     if(is.null(series)) series <- deparse(substitute(x))
-    if(ists <- is.ts(x)) xtsp <- tsp(x)
+    ists <- is.ts(x)
     x <- na.action(as.ts(x))
     xfreq <- frequency(x)
-    x <- as.matrix(x)
     if(any(is.na(x))) stop("NAs in x")
+    if(ists)  xtsp <- tsp(x)
+    x <- as.matrix(x)
     n.used <- nrow(x)
     nser <- ncol(x)
     order.max <- if (is.null(order.max)) floor(10 * log10(n.used))
