@@ -1,6 +1,8 @@
 /*
  *  R : A Computer Language for Statistical Data Analysis
  *  Copyright (C) 1995, 1996  Robert Gentleman and Ross Ihaka
+ *  Copyright (C) 1997--1999  Robert Gentleman, Ross Ihaka and the
+ *                            R Development Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Pulic License as published by
@@ -14,9 +16,13 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <Rconfig.h>
+#endif
+
 #include "Defn.h"
 
 /* Functions to perform analogues of the standard C string library. */
@@ -43,6 +49,31 @@ SEXP do_nchar(SEXP call, SEXP op, SEXP args, SEXP env)
     return s;
 }
 
+static char *buff=NULL;		/* Buffer for character strings */
+
+static void AllocBuffer(int len)
+{
+    static int bufsize = 0;
+
+    if(len >= 0 ) {
+	if(len*sizeof(char) < bufsize) return;
+	len = (len+1)*sizeof(char);
+	if(len < MAXELTSIZE) len = MAXELTSIZE;
+	buff = (char *) realloc(buff, len);
+	bufsize = len;
+	if(!buff) {
+	    bufsize = 0;
+	    error("Could not allocate memory for substr / strsplit");
+	}
+    } else {
+	if(bufsize == MAXELTSIZE) return;
+ /* frees if non-zero */
+	realloc(buff, 0);
+	buff = (char *) realloc(buff, MAXELTSIZE);
+	bufsize = MAXELTSIZE;
+    }
+}
+
 
 static void substr(char *buf, char *str, int sa, int so)
 {
@@ -58,7 +89,7 @@ SEXP do_substr(SEXP call, SEXP op, SEXP args, SEXP env)
 {
     SEXP s, x, sa, so;
     int i, len, start, stop, slen, k, l;
-    char buff[MAXELTSIZE];
+/*    char buff[MAXELTSIZE];*/
 
     checkArity(op, args);
     x = CAR(args);
@@ -79,20 +110,23 @@ SEXP do_substr(SEXP call, SEXP op, SEXP args, SEXP env)
 	if (start < 1)
 	    start = 1;
 	if (start > stop || start > slen) {
+	    AllocBuffer(1);
 	    buff[0]='\0';
 	}
 	else {
+	    AllocBuffer(slen);
 	    if (stop > slen)
 		stop = slen;
-	    if (stop > MAXELTSIZE) {
+	    /* if (stop > MAXELTSIZE) {
 		stop = MAXELTSIZE;
-		warningcall(call, "a string was truncated in substr()\n");
-	    }
+		warningcall(call, "a string was truncated in substr()");
+		}*/
 	    substr(buff, CHAR(STRING(x)[i]), start, stop);
 	}
 	STRING(s)[i] = mkChar(buff);
     }
     UNPROTECT(1);
+    AllocBuffer(-1);
     return s;
 }
 
@@ -103,21 +137,6 @@ SEXP do_substr(SEXP call, SEXP op, SEXP args, SEXP env)
 /* returned of length equal to the input vector x, each element of the */
 /* list is the collection of splits for the corresponding element of x. */
 
-static char *buff=NULL;		/* Buffer for character strings */
-
-static void AllocBuffer(int len)
-{
-    static int bufsize=0;		/* Current buffer size */
-    if(len < bufsize) return;
-    len = (len+1)*sizeof(char);
-    if(len < MAXELTSIZE) len = MAXELTSIZE;
-    buff = (char *) realloc(buff, len);
-    if(!buff) {
-	bufsize = 0;
-	error("Could not allocate memory for strsplit");
-    }
-}
-
 SEXP do_strsplit(SEXP call, SEXP op, SEXP args, SEXP env)
 {
     SEXP s, t, tok, x;
@@ -168,6 +187,7 @@ SEXP do_strsplit(SEXP call, SEXP op, SEXP args, SEXP env)
 	VECTOR(s)[i] = t;
     }
     UNPROTECT(1);
+    AllocBuffer(-1);
     return s;
 }
 
