@@ -23,10 +23,10 @@
 
 #include "Defn.h"
 #include "Mathlib.h"
-#include "Fortran.h"/* POW_DI */
-#include "Applic.h"/* cpoly */
+#include "Fortran.h"		/* POW_DI */
+#include "Applic.h"		/* cpoly */
 
-#include "arithmetic.h"/* complex_ */
+#include "arithmetic.h"		/* complex_ */
 
 static int naflag;
 
@@ -61,7 +61,7 @@ SEXP complex_unary(int code, SEXP s1)
 	return ans;
     default:
 	error("illegal complex unary operator\n");
-	return R_NilValue;/* -Wall*/
+	return R_NilValue;	/* -Wall*/
     }
 }
 
@@ -100,15 +100,19 @@ static void complex_pow(complex *r, complex *a, complex *b)
     double logr, logi, x, y;
     int ib;
 
-    if(b->i == 0.) {/* be fast (and more accurate)*/
-	if(b->r == 1.) { /* a^1 */ r->r = a->r; r->i = a->i; return;}
-	if(a->i == 0.) { r->r = pow(a->r, b->r); r->i = 0.; return;}
+    if(b->i == 0.) {		/* be fast (and more accurate)*/
+	if(b->r == 1.) {	/* a^1 */
+	    r->r = a->r; r->i = a->i; return;
+	}
+	if(a->i == 0.) {
+	    r->r = pow(a->r, b->r); r->i = 0.; return;
+	}
 	if(a->r == 0. && b->r == (ib = (int)b->r)) {/* (|a|*i)^b */
 	    x = POW_DI(&(a->i), &ib);
-	    if(ib % 2) { /* ib is odd ==> imaginary r */
+	    if(ib % 2) {	/* ib is odd ==> imaginary r */
 		r->r = 0.;
 		r->i = ((ib>0 && ib %4 == 3)||(ib<0 && (-ib)%4 == 1))? -x : x;
-	    } else { /* even exponent b : real r */
+	    } else {		/* even exponent b : real r */
 		r->r = (ib %4)? -x : x; r->i = 0.;
 	    }
 	    return;
@@ -248,7 +252,7 @@ SEXP complex_binary(int code, SEXP s1, SEXP s2)
 
 SEXP do_cmathfuns(SEXP call, SEXP op, SEXP args, SEXP env)
 {
-    SEXP x, y = R_NilValue;/* -Wall*/
+    SEXP x, y = R_NilValue;	/* -Wall*/
     int i, n;
 
     checkArity(op, args);
@@ -267,6 +271,7 @@ SEXP do_cmathfuns(SEXP call, SEXP op, SEXP args, SEXP env)
 		REAL(y)[i] = COMPLEX(x)[i].i;
 	    break;
 	case 3:	/* Mod */
+	case 6:	/* abs */
 	    y = allocVector(REALSXP, n);
 	    for(i=0 ; i<n ; i++) {
 #ifdef IEEE_754
@@ -336,6 +341,7 @@ SEXP do_cmathfuns(SEXP call, SEXP op, SEXP args, SEXP env)
 		    REAL(y)[i] = 0;
 	    break;
 	case 3:	/* Mod */
+	case 6:	/* abs */
 	    y = allocVector(REALSXP, n);
 	    for(i=0 ; i<n ; i++) {
 #ifdef IEEE_754
@@ -366,8 +372,8 @@ static void z_rround(complex *r, complex *x, complex *p)
     r->i = rround(x->i, p->r);
 }
 
-	/* Question:  This treats real and imaginary parts */
-	/* separately.	Should it do them jointly? */
+/* Question:  This treats real and imaginary parts separately.  Should
+   it do them jointly? */
 
 static void z_prec(complex *r, complex *x, complex *p)
 {
@@ -576,19 +582,15 @@ SEXP complex_math1(SEXP call, SEXP op, SEXP args, SEXP env)
 {
     SEXP x, y;
     int n;
-    x = CAR(args);
+    PROTECT(x = CAR(args));
     n = length(x);
-    y = allocVector(CPLXSXP, n);
+    PROTECT(y = allocVector(CPLXSXP, n));
     naflag = 0;
 
     switch (PRIMVAL(op)) {
     case 10002: cmath1(z_atan, COMPLEX(x), COMPLEX(y), n); break;
     case 10003: cmath1(z_log, COMPLEX(x), COMPLEX(y), n); break;
 
-    case 0:
-	errorcall(call,
-		  "abs() unimplemented for complex; use Mod()\n");
-	break;
     case 3:  cmath1(z_sqrt, COMPLEX(x), COMPLEX(y), n); break;
 
     case 10: cmath1(z_exp, COMPLEX(x), COMPLEX(y), n); break;
@@ -614,7 +616,11 @@ SEXP complex_math1(SEXP call, SEXP op, SEXP args, SEXP env)
     default:
 	errorcall(call, "unimplemented complex function\n");
     }
-    if (naflag) warning("NAs produced in function \"%s\"", PRIMNAME(op));
+    if (naflag)
+	warning("NAs produced in function \"%s\"", PRIMNAME(op));
+    ATTRIB(y) = duplicate(ATTRIB(x));
+    OBJECT(y) = OBJECT(x);
+    UNPROTECT(2);
     return y;
 }
 
@@ -628,6 +634,8 @@ static SEXP cmath2(SEXP op, SEXP sa, SEXP sb, void (*f)())
 
     na = length(sa);
     nb = length(sb);
+    if ((na == 0) || (nb == 0))
+	return(allocVector(CPLXSXP, 0));
     n = (na < nb) ? nb : na;
     PROTECT(sa = coerceVector(sa, CPLXSXP));
     PROTECT(sb = coerceVector(sb, CPLXSXP));
@@ -635,35 +643,28 @@ static SEXP cmath2(SEXP op, SEXP sa, SEXP sb, void (*f)())
     a = COMPLEX(sa);
     b = COMPLEX(sb);
     y = COMPLEX(sy);
-    if (na < 1 || na < 1) {
-	for (i = 0; i < n; i++) {
+    naflag = 0;
+    for (i = 0; i < n; i++) {
+	ai = a[i % na];
+	bi = b[i % nb];
+	if(ISNA(ai.r) && ISNA(ai.i) &&
+	   ISNA(bi.r) && ISNA(bi.i)) {
 	    y[i].r = NA_REAL;
 	    y[i].i = NA_REAL;
 	}
-    }
-    else {
-	naflag = 0;
-	for (i = 0; i < n; i++) {
-	    ai = a[i % na];
-	    bi = b[i % nb];
-	    if(ISNA(ai.r) && ISNA(ai.i) &&
-	       ISNA(bi.r) && ISNA(bi.i)) {
+	else {
+	    f(&y[i], &ai, &bi);
+#ifndef IEEE_754
+	    if(ISNA(y[i].r) || ISNA(y[i].i)) {
 		y[i].r = NA_REAL;
 		y[i].i = NA_REAL;
+		naflag = 1;
 	    }
-	    else {
-		f(&y[i], &ai, &bi);
-#ifndef IEEE_754
-		if(ISNA(y[i].r) || ISNA(y[i].i)) {
-		    y[i].r = NA_REAL;
-		    y[i].i = NA_REAL;
-		    naflag = 1;
-		}
 #endif
-	    }
 	}
     }
-    if (naflag) warning("NAs produced in function \"%s\"", PRIMNAME(op));
+    if (naflag)
+	warning("NAs produced in function \"%s\"", PRIMNAME(op));
     if(n == na) {
 	ATTRIB(sy) = duplicate(ATTRIB(sa));
 	OBJECT(sy) = OBJECT(sa);
@@ -693,7 +694,7 @@ SEXP complex_math2(SEXP call, SEXP op, SEXP args, SEXP env)
 	return cmath2(op, CAR(args), CADR(args), z_atan2);
     default:
 	errorcall(call, "unimplemented complex function\n");
-	return call;/* just for -Wall */
+	return call;		/* just for -Wall */
     }
 }
 
