@@ -232,10 +232,8 @@ int R_sysparent(int n, RCNTXT *cptr)
 	cptr = cptr->nextcontext;
     }
     n = j - n + 1;
-    if (n == 0)
-	n = 1;
     if (n < 0)
-	error("sys.parent: not that many enclosing functions\n");
+	n = 0;
     return n;
 }
 
@@ -307,7 +305,7 @@ SEXP R_sysfunction(int n, RCNTXT *cptr)
     return R_NilValue;  /* just for -Wall */
 }
 
-/*some real insantiy to keep Duncan sane*/
+/* some real insanity to keep Duncan sane */
 
 SEXP do_restart(SEXP call, SEXP op, SEXP args, SEXP rho)
 {
@@ -361,8 +359,14 @@ SEXP do_sys(SEXP call, SEXP op, SEXP args, SEXP rho)
 	errorcall(call, "invalid number of environment levels\n");
     switch (PRIMVAL(op)) {
     case 1: /* parent */
+	nframe = framedepth(cptr);
 	rval = allocVector(INTSXP,1);
-	INTEGER(rval)[0] = R_sysparent(n, cptr);
+	i = nframe;
+	/* This is a pretty awful kludge, but the alternative would be
+	   a major redesign of everything... -pd */
+	while (n-- > 0)
+	    i = R_sysparent(nframe - i + 1, cptr);
+	INTEGER(rval)[0] = i;
 	return rval;
     case 2: /* call */
 	return R_syscall(n, cptr);
@@ -389,8 +393,8 @@ SEXP do_sys(SEXP call, SEXP op, SEXP args, SEXP rho)
 	UNPROTECT(1);
 	return rval;
     case 7: /* sys.on.exit */
-	if( R_GlobalContext->conexit )
-	    return R_GlobalContext->conexit;
+	if( R_GlobalContext->nextcontext != NULL )
+	    return R_GlobalContext->nextcontext->conexit;
 	else
 	    return R_NilValue;
     case 8: /* sys.parents */
