@@ -15,11 +15,16 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <Rconfig.h>
+#endif
+
 #include "Defn.h"
 #include "FFDecl.h"
+
 /* These are the  R interface routines to the
  * plain FFT code  in ../appl/fft.c
  * NOTE: That one     ~~~~~~~~~~~~~  (and hence the code here) uses
