@@ -14,9 +14,13 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <Rconfig.h>
+#endif
+
 #include "Defn.h"
 
 
@@ -104,7 +108,7 @@ static SEXP lbinary(SEXP call, SEXP op, SEXP args)
 	}
     }
     if(mismatch)
-	warningcall(call, "longer object length\n\tis not a multiple of shorter object length\n");
+	warningcall(call, "longer object length\n\tis not a multiple of shorter object length");
 
     x = CAR(args) = coerceVector(x, LGLSXP);
     y = CADR(args) = coerceVector(y, LGLSXP);
