@@ -1203,7 +1203,7 @@ static SEXP ConvertPairToVector(SEXP obj)
 
 void R_LoadSavedData(FILE *fp, SEXP aenv)
 {
-    SEXP a, ans, e;
+    SEXP a, ans;
     ans = R_LoadFromFile(fp, 0);
 
     /* Store the components of the list in the Global Env */
@@ -1242,13 +1242,13 @@ void R_LoadSavedData(FILE *fp, SEXP aenv)
 
 SEXP do_load(SEXP call, SEXP op, SEXP args, SEXP env)
 {
-    SEXP aenv;
+    SEXP fname, aenv;
     FILE *fp;
 
     checkArity(op, args);
 
-    if (TYPEOF(CAR(args)) != STRSXP)
-	errorcall(call, "first argument must be a string\n");
+    if (!isValidString(fname = CAR(args)))
+	errorcall (call, "first argument must be a file name\n");
 
     /* GRW 1/26/99 GRW : added environment parameter so that */
     /* the loaded objects can be placed where desired  */
@@ -1258,7 +1258,7 @@ SEXP do_load(SEXP call, SEXP op, SEXP args, SEXP env)
 	error("invalid envir argument\n");
 
     /* Process the saved file to obtain a list of saved objects. */
-    fp = R_fopen(R_ExpandFileName(CHAR(STRING(CAR(args))[0])), "rb");
+    fp = R_fopen(R_ExpandFileName(CHAR(STRING(fname)[0])), "rb");
     if (!fp)
 	errorcall(call, "unable to open file\n");
     R_LoadSavedData(fp, aenv);
@@ -1379,6 +1379,7 @@ permute (struct permute_info *pinfo, unsigned dimnum)
 	    break;
 	  default:
 	    errorcall (pinfo->call, "No support for R type: %d", pinfo->type);
+	    pointaddr = &offset;/* unreached; -Wall */
 	  }
 
 	if (pinfo->writeflag)
@@ -1455,28 +1456,28 @@ vector_io (SEXP call, int writeflag, hid_t dataset, hid_t space, SEXP obj)
   if ((tid = H5Dget_type (dataset)) < 0)
     errorcall (call, "Unable to get type for dataset");
 
-  if (type == STRSXP)
-    {
+  switch (type) {
+
+  case STRSXP:
       memtid = make_sexp_ref_type (call);
       buf = STRING (obj);
-    }
-  else if (type == REALSXP)
-    {
+      break;
+  case REALSXP:
       memtid = H5T_NATIVE_DOUBLE;
       buf = REAL (obj);
-    }
-  else if (type == INTSXP)
-    {
+      break;
+  case INTSXP:
       memtid = H5T_NATIVE_INT;
       buf = INTEGER (obj);
-    }
-  else if (type == LGLSXP)
-    {
+      break;
+  case LGLSXP:
       memtid = H5T_NATIVE_UINT;
       buf = INTEGER (obj);
-    }
-  else
+      break;
+  default:
       errorcall (call, "Can't get type for R type: %d (IO)", type);
+      /* unreached (-Wall): */ memtid = tid;  buf = &tid;
+  }
 
   if (H5Sget_simple_extent_dims (space, dims, maxdims) < 0)
     errorcall (call, "Unable to get dimensions of space");
@@ -1506,8 +1507,7 @@ vector_io (SEXP call, int writeflag, hid_t dataset, hid_t space, SEXP obj)
   if (H5Sclose (mspace) < 0)
     errorcall (call, "Unable to close point space");
 
-  if (type == STRSXP)
-    {
+  if (type == STRSXP) {
       if (H5Tclose (memtid) < 0)
 	errorcall (call, "Unable to close string reference type");
     }
@@ -1527,7 +1527,7 @@ hdf5_save_attributes (SEXP call, hid_t loc_id, SEXP val)
       hid_t tid, memtid;
       hid_t sid, aid;
       unsigned count = LENGTH (attr);
-      SEXPREC *stringptrs[count];
+      /*SEXPREC *stringptrs[count];*/
 
       if (TAG (l) == R_RowNamesSymbol
 	  || TAG (l) == R_ClassSymbol
@@ -1605,7 +1605,7 @@ hdf5_write_vector (SEXP call, hid_t id, const char *symname, SEXP val)
   unsigned i, rank;
   SEXP dimvec;
   hid_t space, dataset;
-  int type = TYPEOF (val);
+  SEXPTYPE type = TYPEOF (val);
   hid_t tid;
 
   dimvec = getAttrib (val, R_DimSymbol);
@@ -1618,7 +1618,7 @@ hdf5_write_vector (SEXP call, hid_t id, const char *symname, SEXP val)
       for (i = 0; i < rank; i++)
 	dims[i] = INTEGER (dimvec)[i];
     else
-      dims[0] = LENGTH (val);
+      dims[0] = length(val);
 
     if ((space = H5Screate_simple (rank, dims, NULL)) < 0)
       errorcall (call, "Unable to create file dataspace");
@@ -1635,8 +1635,10 @@ hdf5_write_vector (SEXP call, hid_t id, const char *symname, SEXP val)
       tid = H5T_NATIVE_INT;
     else if (type == REALSXP)
       tid = H5T_NATIVE_DOUBLE;
-    else
+    else {
       errorcall (call, "Can't get type for R type: %d (Creating)", type);
+      tid = H5T_NATIVE_INT;/*unreached; -Wall*/
+    }
 
     if ((dataset = H5Dcreate (id,
 			      symname,
@@ -1711,7 +1713,7 @@ create_rownames_dataset_attribute (SEXP call, hid_t dataset, SEXP rownames)
 {
   hid_t stringtid = get_string_type (call, rownames);
   hid_t rtid = make_sexp_ref_type (call);
-  hid_t rnattrib, rndataspace, itemdata;
+  hid_t rnattrib, rndataspace;
   unsigned rowcount = LENGTH (rownames);
   hsize_t dims[1];
 
@@ -1848,7 +1850,7 @@ hdf5_save_object (SEXP call, hid_t fid, const char *symname, SEXP val)
 		  case STRSXP:
 		    {
 		      SEXP stritem = STRING (item)[ri];
-		      size_t len = LENGTH (stritem);
+		      /*size_t len = LENGTH (stritem);*/
 
 		      memset (ptr, 0, H5Tget_size (hdftypes[pos]));
 		      strcpy ((char *)ptr, CHAR (stritem));
@@ -1895,7 +1897,7 @@ hdf5_save_object (SEXP call, hid_t fid, const char *symname, SEXP val)
     }
   else
     {
-      int type = TYPEOF (val);
+      SEXPTYPE type = TYPEOF (val);
 
       switch (type)
 	{
@@ -1973,15 +1975,13 @@ static void
 hdf5_save_symbol (SEXP call, hid_t fid, SEXP sym, SEXP env)
 {
   SEXP val;
-  int type;
 
   val = findVar (sym, env);
 
   hdf5_save_object (call, fid, CHAR (PRINTNAME (sym)), val);
 }
 
-SEXP
-do_hdf5save (SEXP call, SEXP op, SEXP args, SEXP env)
+SEXP do_hdf5save (SEXP call, SEXP op, SEXP args, SEXP env)
 {
   const char *path;
   hid_t fid;
@@ -2283,8 +2283,8 @@ hdf5_process_object (hid_t id, const char *name, void *client_data)
     {
       hid_t dataset, space, tid;
       int rank;
-      int type;
-      H5T_class_t class;
+      SEXPTYPE type = NILSXP;
+      /*H5T_class_t class;*/
 
       if ((dataset = H5Dopen (id, name)) < 0)
 	errorcall (iinfo->call, "unable to load dataset `%s'", name);
@@ -2354,7 +2354,7 @@ hdf5_process_object (hid_t id, const char *name, void *client_data)
 		size_t csize = H5Tget_size (ctid);
 		size_t coffset = H5Tget_member_offset (tid, ci);
 		SEXPREC **rowptr = &VECTOR (vec)[ci];
-		unsigned char itembuf[size]; // for overrun
+		unsigned char itembuf[size]; /* for overrun */
 
 #define VECLOOP(vectype, vecref, dtid) \
   { \
@@ -2374,8 +2374,7 @@ hdf5_process_object (hid_t id, const char *name, void *client_data)
 		  if (colname)
 		    STRING (names)[ci] = mkChar (colname);
 		}
-		switch (class)
-		  {
+		switch (class) {
 		  case H5T_INTEGER:
 		    {
 		      SEXPTYPE type = (csize == 1) ? LGLSXP : INTSXP;
@@ -2452,25 +2451,23 @@ add_to_return_list (struct hdf5_iterate_info *iinfo,
   UNPROTECT (1);
 }
 
-SEXP
-do_hdf5load (SEXP call, SEXP op, SEXP args, SEXP env)
+SEXP do_hdf5load (SEXP call, SEXP op, SEXP args, SEXP env)
 {
   const char *path;
   hid_t fid;
   int restore_syms;
-  SEXP rl;
   struct hdf5_iterate_info iinfo;
 
   checkArity (op, args);
 
-  if (TYPEOF (CAR (args)) != STRSXP)
+  if (!isValidString(CAR(args)))
     errorcall (call, "first argument must be a pathname\n");
 
   if (TYPEOF (CADR (args)) != LGLSXP)
     errorcall (call, "second argument must be a logical vector\n");
 
-  path = CHAR (STRING (CAR (args))[0]);
-  restore_syms = INTEGER (CADR (args))[0];
+  path = CHAR(STRING (CAR(args))[0]);
+  restore_syms = INTEGER (CADR(args))[0];
 
   H5dont_atexit ();
 
@@ -2497,20 +2494,19 @@ do_hdf5load (SEXP call, SEXP op, SEXP args, SEXP env)
   if (H5Fclose (fid) < 0)
     errorcall (call, "unable to close HDF file");
 
-
   return iinfo.ret;
 }
+
 #else
-SEXP
-do_hdf5save (SEXP call, SEXP op, SEXP args, SEXP env)
+
+SEXP do_hdf5save (SEXP call, SEXP op, SEXP args, SEXP env)
 {
     errorcall(call, "HDF5 support unavailable\n");
-    return(R_NilValue);		      /* -Wall */
+    return(R_NilValue);/* -Wall */
 }
-SEXP
-do_hdf5load (SEXP call, SEXP op, SEXP args, SEXP env)
+SEXP do_hdf5load (SEXP call, SEXP op, SEXP args, SEXP env)
 {
     errorcall(call, "HDF5 support unavailable\n");
-    return(R_NilValue);		      /* -Wall */
+    return(R_NilValue);/* -Wall */
 }
 #endif
