@@ -14,9 +14,13 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <Rconfig.h>
+#endif
+
 #include "Defn.h"
 
 SEXP do_split(SEXP call, SEXP op, SEXP args, SEXP env)
@@ -40,7 +44,7 @@ SEXP do_split(SEXP call, SEXP op, SEXP args, SEXP env)
     if (nfac <= 0)
 	errorcall(call, "Group length is 0 but data length > 0");
     if (nobs != nfac)
-	warningcall(call, "argument lengths differ\n");
+	warningcall(call, "argument lengths differ");
     PROTECT(counts = allocVector(INTSXP, nlevs));
     for (i = 0; i < nlevs; i++)
 	INTEGER(counts)[i] = 0;
