@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *
  *  Subset Mutation for Lists and Vectors
@@ -62,6 +62,10 @@
  *  "ifelse" requires assignment into a logical object.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <Rconfig.h>
+#endif
+
 #include "Defn.h"
 
 static SEXP gcall;
@@ -78,7 +82,7 @@ static SEXP EnlargeVector(SEXP x, int newlen)
 
     /* Sanity Checks */
     if (LOGICAL(GetOption(install("check.bounds"), R_NilValue))[0])
-	warning("assignment outside vector/list limits\n");
+	warning("assignment outside vector/list limits");
     if (!isVector(x))
 	error("attempt to enlarge non-vector\n");
 
@@ -220,6 +224,14 @@ static void SubassignTypeFix(SEXP *x, SEXP *y,
 	}
 	break;
 
+    case 1019:  /* logical    <- vector     */
+    case 1319:  /* integer    <- vector     */
+    case 1419:  /* real       <- vector     */
+    case 1519:  /* complex    <- vector     */
+    case 1619:  /* character  <- vector     */
+	*x = coerceVector(*x, VECSXP);
+	break;
+
     case 2001:	/* expression <- symbol	    */
     case 2006:	/* expression <- language   */
     case 2010:	/* expression <- logical    */
@@ -331,7 +343,7 @@ static SEXP VectorAssign(SEXP call, SEXP x, SEXP s, SEXP y)
 	if (n > 0 && ny == 0)
 	    errorcall(call, "nothing to replace with\n");
 	if (n > 0 && n % ny)
-	    warning("number of items to replace is not a multiple of replacement length\n");
+	    warning("number of items to replace is not a multiple of replacement length");
     }
 
     PROTECT(x);
@@ -1313,18 +1325,22 @@ SEXP do_subassign2(SEXP call, SEXP op, SEXP args, SEXP rho)
     PROTECT(CDR(args) = EvalSubassignArgs(CDR(args), rho));
     SubAssignArgs(args, &x, &subs, &y);
 
-    if (length(x) == 0) {
-	if (length(y) > 1)
-	    x = coerceVector(x, VECSXP);
-	else if (length(y) == 1) {
-	    if (TYPEOF(x) != VECSXP)
-		x = coerceVector(x, TYPEOF(y));
-	}
-	else {
-	    UNPROTECT(1);
-	    return(x);
-	}
+    /* Handle NULL left-hand sides.  If the right-hand side */
+    /* is NULL, just return the left-hand size otherwise, */
+    /* convert to a zero length list (VECSXP). */
+
+    if (isNull(x)) {
+        if (isNull(y)) {
+            UNPROTECT(1);
+	    return x;
+        }
+        UNPROTECT(1);
+        PROTECT(x = allocVector(TYPEOF(y), 0));
     }
+
+    /* Ensure that the LHS is a local variable. */
+    /* If it is not, then make a local copy. */
+
     if (NAMED(x) == 2) {
 	CAR(args) = x = duplicate(x);
     }
@@ -1446,6 +1462,12 @@ SEXP do_subassign2(SEXP call, SEXP op, SEXP args, SEXP rho)
 	    STRING(x)[offset] = STRING(y)[0];
 	    break;
 
+	case 1019:      /* logical    <- vector     */
+	case 1319:      /* integer    <- vector     */
+	case 1419:      /* real       <- vector     */
+	case 1519:      /* complex    <- vector     */
+	case 1619:      /* character  <- vector     */
+
 	case 1901:	/* vector     <- symbol	    */
 	case 1906:	/* vector     <- language   */
 	case 1910:      /* vector     <- logical    */
@@ -1457,7 +1479,6 @@ SEXP do_subassign2(SEXP call, SEXP op, SEXP args, SEXP rho)
 	    VECTOR(x)[offset] = VECTOR(y)[0];
 	    break;
 
-
 	case 2001:	/* expression <- symbol	    */
 	case 2006:	/* expression <- language   */
 	case 2010:	/* expression <- logical    */
@@ -1589,7 +1610,7 @@ SEXP do_subassign3(SEXP call, SEXP op, SEXP args, SEXP env)
 	SEXP names;
 
 	if (!(isNewList(x) || isExpression(x))) {
-	    warning("Coercing LHS to a list\n");
+	    warning("Coercing LHS to a list");
 	    x = coerceVector(x, VECSXP);
 	}
 	names = getAttrib(x, R_NamesSymbol);
