@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA.
  *
  *  SYNOPSIS
  *
@@ -28,7 +28,7 @@
  *  NOTES
  *
  *    This function is based on the Applied Statistics
- *    Algorithm AS 91 and AS 239.
+ *    Algorithm AS 91 ("ppchi2") and via pgamma(.) AS 239.
  *
  *  REFERENCES
  *
@@ -44,47 +44,20 @@
 #define C9	6.73
 #define C10	13.32
 
-#define C11	60
-#define C12	70
-#define C13	84
-#define C14	105
-#define C15	120
-#define C16	127
-#define C17	140
-#define C18	1175
-#define C19	210
-
-#define C20	252
-#define C21	2264
-#define C22	294
-#define C23	346
-#define C24	420
-#define C25	462
-#define C26	606
-#define C27	672
-#define C28	707
-#define C29	735
-
-#define C30	889
-#define C31	932
-#define C32	966
-#define C33	1141
-#define C34	1182
-#define C35	1278
-#define C36	1740
-#define C37	2520
-#define C38	5040
-
-#define EPS0 5e-7/* originally: IDENTICAL to EPS2; not clear why */
 #define EPS1 1e-2
-#define EPS2 5e-7
-#define MAXIT 20
+#define EPS2 5e-7/* final precision */
+#define MAXIT 1000/* was 20 */
 
-#define pMIN 0.000002
-#define pMAX 0.999998
+#define pMIN 1e-100    /* was 0.000002 = 2e-6 */
+#define pMAX (1-1e-12)/* was 0.999998 = 1 - 2e-6 */
 
 double qgamma(double p, double alpha, double scale)
 {
+    static const double
+	i420  = 1./ 420.,
+	i2520 = 1./ 2520.,
+	i5040 = 1./ 5040;
+
     double a, b, c, ch, g, p1, v;
     double p2, q, s1, s2, s3, s4, s5, s6, t, x;
     int i;
@@ -108,18 +81,18 @@ double qgamma(double p, double alpha, double scale)
     c = alpha-1;
     g = lgammafn(alpha);/* log Gamma(v/2) */
 
-    if(v < (-1.24)*log(p)) {
-      /* starting approximation for small chi-squared */
+
+/*----- Phase I : Starting Approximation */
+
+
+    if(v < (-1.24)*log(p)) {	/* for small chi-squared */
 
 	ch = pow(p*alpha*exp(g+alpha*M_LN2), 1/alpha);
-	if(ch < EPS0) {
-	    ML_ERROR(ME_DOMAIN);
-	    return ML_NAN;
+	if(ch < EPS2) {/* Corrected according to AS 91; MM, May 25, 1999 */
+	    goto END;
 	}
 
-    } else if(v > 0.32) {
-
-	/* starting approximation using Wilson and Hilferty estimate */
+    } else if(v > 0.32) {	/*  using Wilson and Hilferty estimate */
 
 	x = qnorm(p, 0, 1);
 	p1 = 0.222222/v;
@@ -130,27 +103,28 @@ double qgamma(double p, double alpha, double scale)
 	if( ch > 2.2*v + 6 )
 	    ch = -2*(log(1-p) - c*log(0.5*ch) + g);
 
-    } else { /* starting approximation for v <= 0.32 */
+    } else { /* for v <= 0.32 */
 
 	ch = 0.4;
 	a = log(1-p) + g + c*M_LN2;
 	do {
 	    q = ch;
-	    p1 = 1+ch*(C7+ch);
+	    p1 = 1. / (1+ch*(C7+ch));
 	    p2 = ch*(C9+ch*(C8+ch));
-	    t = -0.5 +(C7+2*ch)/p1 - (C9+ch*(C10+3*ch))/p2;
-	    ch -= (1- exp(a+0.5*ch)*p2/p1)/t;
-	} while(fabs(q/ch - 1) > EPS1);
+	    t = -0.5 +(C7+2*ch)*p1 - (C9+ch*(C10+3*ch))/p2;
+	    ch -= (1- exp(a+0.5*ch)*p2*p1)/t;
+	} while(fabs(q - ch) > EPS1*fabs(ch));
     }
 
-    /* algorithm AS 239 and calculation of seven term taylor series */
-
+/*----- Phase II: Iteration
+ *	Call pgamma() [AS 239]  and calculate seven term taylor series
+ */
     for( i=1 ; i <= MAXIT ; i++ ) {
 	q = ch;
 	p1 = 0.5*ch;
 	p2 = p - pgamma(p1, alpha, 1);
 #ifdef IEEE_754
-	if(!finite(p2))
+	if(!R_FINITE(p2))
 #else
 	if(errno != 0)
 #endif
@@ -158,17 +132,18 @@ double qgamma(double p, double alpha, double scale)
 
 	t = p2*exp(alpha*M_LN2+g+p1-c*log(ch));
 	b = t/ch;
-	a = 0.5*t-b*c;
-	s1 = (C19+a*(C17+a*(C14+a*(C13+a*(C12+C11*a)))))/C24;
-	s2 = (C24+a*(C29+a*(C32+a*(C33+C35*a))))/C37;
-	s3 = (C19+a*(C25+a*(C28+C31*a)))/C37;
-	s4 = (C20+a*(C27+C34*a)+c*(C22+a*(C30+C36*a)))/C38;
-	s5 = (C13+C21*a+c*(C18+C26*a))/C37;
-	s6 = (C15+c*(C23+C16*c))/C38;
-	ch = ch+t*(1+0.5*t*s1-b*c*(s1-b*(s2-b*(s3-b*(s4-b*(s5-b*s6))))));
-	if(fabs(q/ch-1) > EPS2)
-	    return 0.5*scale*ch;
+	a = 0.5*t - b*c;
+	s1 = (210+a*(140+a*(105+a*(84+a*(70+60*a))))) * i420;
+	s2 = (420+a*(735+a*(966+a*(1141+1278*a)))) * i2520;
+	s3 = (210+a*(462+a*(707+932*a))) * i2520;
+	s4 = (252+a*(672+1182*a)+c*(294+a*(889+1740*a))) * i5040;
+	s5 = (84+2264*a+c*(1175+606*a)) * i2520;
+	s6 = (120+c*(346+127*c)) * i5040;
+	ch += t*(1+0.5*t*s1-b*c*(s1-b*(s2-b*(s3-b*(s4-b*(s5-b*s6))))));
+	if(fabs(q - ch) < EPS2*ch)
+	    goto END;
     }
     ML_ERROR(ME_PRECISION);
+ END:
     return 0.5*scale*ch;
 }
