@@ -209,10 +209,10 @@ void R_DefParams(Rstart Rp)
 
 #define Max_Nsize 20000000	/* must be < LONG_MAX (= 2^32 - 1 =)
 				   2147483647 = 2.1e9 */
-#define Max_Vsize (2048*Mega)	/* must be < LONG_MAX */
+#define Max_Vsize (2048*Mega)	/* 2048*Mega = 2^(11+20) must be < LONG_MAX */
 
-#define Min_Nsize 200000
-#define Min_Vsize (2*Mega)
+#define Min_Nsize 160000
+#define Min_Vsize (1*Mega)
 
 void R_SizeFromEnv(Rstart Rp)
 {
@@ -271,6 +271,8 @@ void R_SetParams(Rstart Rp)
     LoadInitFile = Rp->LoadInitFile;
     DebugInitFile = Rp->DebugInitFile;
     SetSize(Rp->vsize, Rp-> nsize);
+    CommandLineArgs = Rp->CommandLineArgs;
+    NumCommandLineArgs = Rp->NumCommandLineArgs;
 #ifdef Win32
     R_SetWin32(Rp);
 #endif
@@ -286,6 +288,48 @@ static void R_common_badargs() {
 }
 */
 
+/*
+  This copies the command line arguments to the Rstart
+  structure. The memory is obtained from calloc, etc.
+  since these are permanent and it is not intended that
+  they be modified. This is why they are copied before
+  being processed and removed from the list.
+
+  We might store these as a SEXP. I have no strong opinion
+  about this.
+ */
+void
+R_set_command_line_arguments(int argc, char **argv, Rstart Rp)
+{
+ int i;
+
+  Rp->NumCommandLineArgs = argc;
+  Rp->CommandLineArgs = (char**) calloc(argc, sizeof(char*));
+
+  for(i=0;i < argc; i++) {
+    Rp->CommandLineArgs[i] = strdup(argv[i]);
+  }
+}
+
+
+/*
+  The .Internal which returns the command line arguments
+  that are stored in global variables.
+ */
+SEXP do_commandArgs(SEXP call, SEXP op, SEXP args, SEXP env)
+{
+ int i;
+ SEXP vals;
+
+  vals = allocVector(STRSXP, NumCommandLineArgs);
+  for(i = 0; i < NumCommandLineArgs; i++) {
+    STRING(vals)[i] = mkChar(CommandLineArgs[i]);
+  }
+
+ return(vals);
+}
+
+
 void R_common_command_line(int *pac, char **argv, Rstart Rp)
 {
     int ac = *pac, newac = 1;	/* argv[0] is process name */
@@ -367,7 +411,7 @@ void R_common_command_line(int *pac, char **argv, Rstart Rp)
 		    if(ierr < 0) /* R_common_badargs(); */
 			sprintf(msg, "WARNING: --vsize value is invalid: ignored\n");
 		    else
-			sprintf(msg, "WARNING: --vsize %ld`%c': too large and ignored\n", 
+			sprintf(msg, "WARNING: --vsize %ld`%c': too large and ignored\n",
 				value,
 				(ierr == 1) ? 'M': ((ierr == 2) ? 'K' : 'k'));
 		    R_ShowMessage(msg);
@@ -392,7 +436,7 @@ void R_common_command_line(int *pac, char **argv, Rstart Rp)
 		    if(ierr < 0) /* R_common_badargs(); */
 			sprintf(msg, "WARNING: --nsize value is invalid: ignored\n");
 		    else
-		    sprintf(msg, "WARNING: --nsize %ld`%c': too large and ignored\n", 
+		    sprintf(msg, "WARNING: --nsize %ld`%c': too large and ignored\n",
 			    value,
 			    (ierr == 1) ? 'M': ((ierr == 2) ? 'K':'k'));
 		    R_ShowMessage(msg);
@@ -401,7 +445,6 @@ void R_common_command_line(int *pac, char **argv, Rstart Rp)
 	    }
 	    else {
 		argv[newac++] = *av;
-		break;
 	    }
 	}
 	else {
