@@ -10,8 +10,8 @@ rErr <- function(approx, true, eps = .Options$rErr.eps)
 {
     if(is.null(eps)) { eps <- 1e-30; options(rErr.eps = eps) }
     ifelse(Mod(true) >= eps,
-           1 - approx / true, # relative error
-           true - approx)     # absolute error (e.g. when true=0)
+	   1 - approx / true, # relative error
+	   true - approx)     # absolute error (e.g. when true=0)
 }
 
 is.infinite(.Machine$double.base ^ .Machine$double.max.exp)# overflow
@@ -20,6 +20,24 @@ abs(1- .Machine$double.xmin * 10^(-.Machine$double.min.exp*log10(2)))/Meps < 1e3
 log10(.Machine$double.xmax) / log10(2) == .Machine$double.max.exp
 log10(.Machine$double.xmin) / log10(2) == .Machine$double.min.exp
 
+##  log() and "pow()" -- POSIX is not specific enough..
+log(0) == -Inf
+is.nan(log(-1))# TRUE and warning
+
+rp <- c(1:2,Inf); rn <- rev(- rp)
+r <- c(rn, 0, rp)
+all(r^0 == 1)
+all((rn ^ -3) == -((-rn) ^ -3))
+#
+all(c(1.1,2,Inf) ^ Inf == Inf)
+all(c(1.1,2,Inf) ^ -Inf == 0)
+.9 ^ Inf == 0
+.9 ^ -Inf == Inf
+## Wasn't ok in 0.64:
+all(1^c(-Inf,Inf) == 1)
+all(is.nan(rn ^ .5))# in some C's : (-Inf) ^ .5 gives Inf, instead of NaN
+
+
 ## Real Trig.:
 cos(0) == 1
 sin(3*pi/2) == cos(pi)
@@ -56,7 +74,7 @@ abs(gamma(1/2)^2 - pi) < 4* Meps
 r <- rlnorm(5000)
 all(abs(rErr(gamma(r+1), r*gamma(r))) < 500 * Meps)
 
-n <-   10; all(          gamma(1:n) == cumprod(c(1,1:(n-1))))
+n <-   10; all(		 gamma(1:n) == cumprod(c(1,1:(n-1))))
 n <-   20; all(abs(rErr( gamma(1:n), cumprod(c(1,1:(n-1))))) < 100*Meps)
 n <-  120; all(abs(rErr( gamma(1:n), cumprod(c(1,1:(n-1))))) < 1000*Meps)
 n <- 10000;all(abs(rErr(lgamma(1:n),cumsum(log(c(1,1:(n-1)))))) < 100*Meps)
@@ -66,14 +84,19 @@ ok <- TRUE
 ##test EXTENSIVELY:	for(N in 1:100) {
     cat(".")
     for(n in c(1:30, 1000:1050)) {
-        x <- rnorm(n)
-        er <- Mod(rErr(fft(fft(x), inverse = TRUE)/n, x*(1+0i)))
-        n.ok <- all(er < 1e-8) & quantile(er, 0.95, names=FALSE) < 10000*Meps
-        if(!n.ok) cat("\nn=",n,": quantile(rErr, c(.95,1)) =",
-                      formatC(quantile(er, prob= c(.95,1))),"\n")
-        ok <- ok & n.ok
+	x <- rnorm(n)
+	er <- Mod(rErr(fft(fft(x), inverse = TRUE)/n, x*(1+0i)))
+	n.ok <- all(er < 1e-8) & quantile(er, 0.95, names=FALSE) < 10000*Meps
+	if(!n.ok) cat("\nn=",n,": quantile(rErr, c(.95,1)) =",
+		      formatC(quantile(er, prob= c(.95,1))),"\n")
+	ok <- ok & n.ok
     }
     cat("\n")
 ##test EXTENSIVELY:	}
 ok
 
+## var():
+for(n in 2:10)
+    print(all.equal(n*(n-1)*var(diag(n)),
+		    matrix(c(rep(c(n-1,rep(-1,n)),n-1), n-1), nr=n, nc=n),
+		    tol = 20*Meps))# use tol=0	to see rel.error
